@@ -3,19 +3,17 @@
  * Developed by Tim Walls <tim.walls@snowgoons.com>
  * Copyright (c) All Rights Reserved, Tim Walls
  */
-//! @todo documentation for this module
-//!
-//!
+//! Simple abstraction of an LED attached to a GPIO pin.
 
 // Imports ===================================================================
-use crate::hal::generic::port::Pin;
+use crate::hal::generic::port::{Pin, PinMode, InterruptMode};
 
 // Declarations ==============================================================
 pub struct Led<P>
 where
-  P: Pin
+  P: 'static + Pin
 {
-  pin: P
+  pin: &'static mut P
 }
 
 // Code ======================================================================
@@ -23,16 +21,18 @@ impl<P> Led<P>
 where
   P: Pin
 {
-  pub fn using_pin(pin: P) -> Self {
+  pub fn using_pin(pin: &'static mut P) -> Self {
+    pin.set_mode(PinMode::Output);
+    pin.set_interrupt_mode(InterruptMode::Disabled);
     Led { pin }
   }
 
   pub fn set_on(&mut self) {
-    todo!()
+    self.pin.set_high();
   }
 
   pub fn set_off(&mut self) {
-    todo!()
+    self.pin.set_low();
   }
 
   pub fn set(&mut self, on: bool) {
