@@ -7,43 +7,45 @@
 // Imports ===================================================================
 use crate::hal::generic::timer::TimerControl;
 use crate::hal::generic::timer::TimerMode::Periodic;
-use crate::event::OxideEventQueue;
+use crate::event::{EventSink, OxideEvent};
 
 use crate::deviceconsts::my::{ MASTER_CLOCK_PRESCALER, MASTER_CLOCK_HZ, MASTER_TICK_PERIOD_CS };
+use core::marker::PhantomData;
 
 // Declarations ==============================================================
 
 
-pub struct MasterClock<T>
+pub struct MasterClock<T,S>
 where
-  T: 'static + TimerControl
+  T: 'static + TimerControl,
+  S: EventSink
 {
   timer: &'static mut T,
-  eventq: &'static OxideEventQueue
+  phantom: PhantomData<S>
 }
 
 
 // Code ======================================================================
 
-impl<T> MasterClock<T>
+impl<T,S> MasterClock<T,S>
 where
-  T: TimerControl
+  T: TimerControl,
+  S: EventSink
 {
-  pub fn new(timer: &'static mut T, eventq: &'static OxideEventQueue) -> Self {
+  pub fn using_timer(timer: &'static mut T) -> Self {
     const PERIPHERAL_CLOCK_HZ: u32  = MASTER_CLOCK_HZ/MASTER_CLOCK_PRESCALER as u32;
     const TIMER_CLOCK_HZ: u32       = PERIPHERAL_CLOCK_HZ/2; // We use CLK_PER/2 in timer config
     const CYCLES_PER_CS: u16        = (TIMER_CLOCK_HZ/100) as u16;
 
     Self {
       timer: timer.mode(Periodic).count_max(CYCLES_PER_CS).interrupting(MASTER_TICK_PERIOD_CS),
-      eventq
+      phantom: PhantomData::default()
     }
   }
 
   pub fn run(&mut self) {
-    self.timer.start(Some(|_ticks:u16| {
-      //let mut led = Hardware::borrow().led_mut(LedFunction::WHITE);
-      //led.toggle();
+    self.timer.start(Some(|ticks:u16| {
+      S::event(OxideEvent::MasterClockEvent(ticks));
       true
     }));
   }
