@@ -7,6 +7,7 @@
 
 // Imports ===================================================================
 use crate::ringq::RingQ;
+use crate::devices::button::ButtonState;
 
 // Declarations ==============================================================
 pub type OxideEventQueue = RingQ<OxideEvent,16>;
@@ -17,10 +18,23 @@ pub type OxideEventQueue = RingQ<OxideEvent,16>;
 #[derive(Clone)]
 pub enum OxideEvent {
   /**
-   * Called when the master clock timer tick interrupt occurs.  The number
+   * Sent when the master clock timer tick interrupt occurs.  The number
    * of elapsed clock ticks is included.
    */
-  MasterClockEvent(u16)
+  MasterClockEvent(u16),
+
+  /**
+   * Sent when a button event occurs.  The state of the button when the
+   * event was generated is included.
+   */
+  ButtonEvent(ButtonState)
+}
+
+/**
+ * An event sink is something that devices can call to dump their events into.
+ */
+pub trait EventSink {
+  fn event(event: OxideEvent) -> ();
 }
 
 // Code ======================================================================
